一句话:提出 SPARE,通过重写 compute-uncompute 门序列并利用 ancilla 状态来优化量子电路,且证明重写正确性。
许多量子算法与高层模块化量子编程语言会引入辅助量子比特(ancilla),并将其降级为嵌套或级联的 compute-uncompute 门序列电路以跟踪内部状态,这带来优化机会。本文提出 SPARE,一种基于重写的量子电路优化器,利用 ancilla 状态信息重构这些门序列;作者证明重写规则的正确性,并把门级变换关联到语言级程序重写。评估在 QPL 生成电路上对比 Unqomp、Spire 以及 Quartz、Feynman、PyZX:相对 Unqomp 最多减少 27.3% 量子比特、56.7% 双量子比特门、68.2% 单量子比特门、73.9% 深度;相对 Spire 也有类似降低,并优于最佳门级优化器。
Many quantum algorithms instantiate and use ancillas, spare qubits that serve as temporary storage in a quantum circuit. In particular, many recently developed high-level and modular quantum programming languages (QPLs) use ancilla qubits to implement various programming constructs. These are lowered to circuits with nested/cascading compute-uncompute gate sequences that use ancilla qubits to track internal state. We present SPARE, a rewrite-based quantum circuit optimizer that restructures these compute-uncompute gate sequences, leveraging the ancilla qubit state information to optimize the circuit. In this work, we prove the correctness of SPARE’s rewrites and link SPARE’s gate-level transforms to language-level program rewrites, which may be performed on the input language. We evaluate SPARE on QPL-generated quantum circuits against Unqomp and Spire, two optimizing compilers for QPLs. SPARE achieves a reduction of up to 27.3 % in qubit count, 56.7 % in 2 -qubit gates, 68.2 % in 1-qubit gates and 73.9 % in depth against Unqomp, and up to 17.8 % in qubits, 67.3 % in 2-qubit gates, 61.4 % in 1-qubit gates and 59.9 % in depth against Spire. We also evaluate SPARE against the Quartz, Feynman, and PyZX circuit optimizers: SPARE achieves up to a 70.0 % reduction in two-qubit gates, up to a 53.6 % reduction in 1-qubit gates, and up to a 56.7 % reduction in depth compared to the best result from all the gate-level optimizers.